Adjust column selection from data sets of type 'adsl' in spec object
Source:R/adjust_spec.R
adjust_adsl_select.RdHelper function to make common adjustments to the spec object built by
\link{adam_spec}() for data sets of type 'adsl' to be used with the %>%.
Arguments
- spec
spec object to modify
- add, drop
character vector of columns to add to/discard from the automated selection that is stored in the
selectentry of the correspondingspecentry (drop wins over add).- select
character vector of column names to be selected. if not NULL (the default), arguments
addanddropwill be ignored. Overridesselectentry of the correspondingspecentry.- entry
name of list element to modify in the spec, defaults to "adsl"
Details
if data is provided, the column names stored in the select slot will be
intersected with actually existing column names.
User will be informed in case of misspecifications.
If a trt column shall be used and is provided in the select slot,
the user has to make sure to update the trt slot accordingly in
adam_spec().