Skip to contents

Check for occurrence of level that would cause issue with lumping

Usage

check_other_class(x, other2_class = NULL, quiet = FALSE)

Arguments

x

data set to check

other2_class

name of class to check for. If NULL (the default), uses the default of step_other2()'s argument other.

quiet

whether to suppress printing messages to the console. defaults to FALSE.

Value

invisibly returns a list for downstream use in check_feature()