Import file and collect info
Arguments
- file
filepath
- catalog_file
path to the catalog file to be passed to
haven::read_sas(). Defaults toNULL. Ignored iffileis not a.sas7bdatfile.
Import file and collect info
filepath
path to the catalog file to be passed to
haven::read_sas(). Defaults to NULL.
Ignored if file is not a .sas7bdat file.