Extract applied filters and (optionally) compare to reference set
Arguments
- spec
spec object as returned by
adam_spec()- filter
if not
NULL(default), applied filters are compared against a reference set, identifying filters that cannot be applied to the data without an error- quiet
if
TRUEinstead of printing message to console, return list with messages on applied and discarded filters. Defaults toFALSE.