Feature matrix of the included example study in system.file("ads", package = "martini")
created by build() from martini_spec.
Format
A tibble with one row per subject and the features in the column. See the documentation of
build() for details on the object structure.