Removes original columns if options apply
Source:R/step_corr_keep.R
martini_remove_original_cols.RdThis helper function should be used whenever the argument
keep_original_cols is used in a function.
R/step_corr_keep.R
martini_remove_original_cols.RdThis helper function should be used whenever the argument
keep_original_cols is used in a function.