Skip to contents

Specification object of the included example study in system.file("martini_example_study/ads", package = "martini") as created by adam_spec().

Usage

martini_spec

Format

A list with the entries adsl, adlb, admh and advs. See the documentation of adam_spec() for further details on the object structure.

Simulated data