e1071 was only used for e1071::skewness in prepare_ml_vars,default type = 3
Arguments
- x
a numeric vector containing the values whose skewness is to be computed.
- na.rm
a logical value indicating whether NA values should be stripped before the computation proceeds.
Value
The estimated skewness of x.