Identify variables that only have only (non-negative) integer values and a relatively small number of distinct values
Value
invisibly returns a list for downstream use in check_feature()
Identify variables that only have only (non-negative) integer values and a relatively small number of distinct values
invisibly returns a list for downstream use in check_feature()