Check for occurrence of level that would cause issue with lumping
Source:R/check_feature.R
check_other_class.RdCheck for occurrence of level that would cause issue with lumping
Arguments
- x
data set to check
- other2_class
name of class to check for. If
NULL(the default), uses the default ofstep_other2()'s argumentother.- quiet
whether to suppress printing messages to the console. defaults to FALSE.
Value
invisibly returns a list for downstream use in check_feature()