This helper function removes columns based on character vectors.
Usage
martini_recipes_remove_cols(new_data, object, col_names = character())This helper function removes columns based on character vectors.
martini_recipes_remove_cols(new_data, object, col_names = character())